summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvasline_imp.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
commit9ba04742771370f59740e32e11c5f3a1e6a1b70a (patch)
treec81c34dae2b3b1ea73801bf18a960265dc4207f7 /kjsembed/qtbindings/qcanvasline_imp.cpp
parent1a96c45b22d01378202d9dc7ed9c47acd30f966e (diff)
downloadtdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.tar.gz
tdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.zip
Initial TQt conversion
Diffstat (limited to 'kjsembed/qtbindings/qcanvasline_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvasline_imp.cpp70
1 files changed, 35 insertions, 35 deletions
diff --git a/kjsembed/qtbindings/qcanvasline_imp.cpp b/kjsembed/qtbindings/qcanvasline_imp.cpp
index 429321f3..af6a7b53 100644
--- a/kjsembed/qtbindings/qcanvasline_imp.cpp
+++ b/kjsembed/qtbindings/qcanvasline_imp.cpp
@@ -23,19 +23,19 @@
*/
namespace KJSEmbed {
-QCanvasLineImp::QCanvasLineImp( KJS::ExecState *exec, int mid, bool constructor )
+TTQCanvasLineImp::TQCanvasLineImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-QCanvasLineImp::~QCanvasLineImp()
+TTQCanvasLineImp::~TQCanvasLineImp()
{
}
/**
* Adds bindings for static methods and enum constants to the specified Object.
*/
-void QCanvasLineImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasLineImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -43,11 +43,11 @@ void QCanvasLineImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &objec
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasLineImp *meth = new QCanvasLineImp( exec, methods[idx].id );
+ TQCanvasLineImp *meth = new TQCanvasLineImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -60,7 +60,7 @@ void QCanvasLineImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &objec
/**
* Adds bindings for instance methods to the specified Object.
*/
-void QCanvasLineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasLineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -74,11 +74,11 @@ void QCanvasLineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasLineImp *meth = new QCanvasLineImp( exec, methods[idx].id );
+ TQCanvasLineImp *meth = new TQCanvasLineImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -87,68 +87,68 @@ void QCanvasLineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TQCanvasLine pointer from an Object.
*/
-TQCanvasLine *QCanvasLineImp::toQCanvasLine( KJS::Object &self )
+TTQCanvasLine *TQCanvasLineImp::toTQCanvasLine( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TQObject *obj = ob->object();
+ TTQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TQCanvasLine *>( obj );
+ return dynamic_cast<TTQCanvasLine *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TQCanvasLine" )
+ if ( op->typeName() != "TTQCanvasLine" )
return 0;
- return op->toNative<TQCanvasLine>();
+ return op->toNative<TTQCanvasLine>();
}
/**
* Select and invoke the correct constructor.
*/
-KJS::Object QCanvasLineImp::construct( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasLineImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
switch( id ) {
case Constructor_QCanvasLine_1:
- return QCanvasLine_1( exec, args );
+ return TQCanvasLine_1( exec, args );
break;
default:
break;
}
- TQString msg = i18n("QCanvasLineCons has no constructor with id '%1'.").arg(id);
+ TTQString msg = i18n("TQCanvasLineCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Object QCanvasLineImp::QCanvasLine_1( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasLineImp::TQCanvasLine_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter TQCanvas *
return KJS::Object();
- TQCanvas * arg0; // Dummy
+ TTQCanvas * arg0; // Dummy
- // We should now create an instance of the TQCanvasLine object
+ // We should now create an instance of the TTQCanvasLine object
- TQCanvasLine *ret = new TQCanvasLine(
+ TTQCanvasLine *ret = new TTQCanvasLine(
arg0 );
}
-KJS::Value QCanvasLineImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
+KJS::Value TQCanvasLineImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QCanvasLineImp::toQCanvasLine( self );
+ instance = TQCanvasLineImp::toTQCanvasLine( self );
switch( id ) {
@@ -180,12 +180,12 @@ KJS::Value QCanvasLineImp::call( KJS::ExecState *exec, KJS::Object &self, const
break;
}
- TQString msg = i18n( "QCanvasLineImp has no method with id '%1'." ).arg( id );
+ TTQString msg = i18n( "TQCanvasLineImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QCanvasLineImp::setPoints_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasLineImp::setPoints_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
@@ -205,25 +205,25 @@ KJS::Value QCanvasLineImp::setPoints_3( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QCanvasLineImp::startPoint_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasLineImp::startPoint_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQPoint ret;
+ TTQPoint ret;
ret = instance->startPoint( );
return convertToValue( exec, ret );
}
-KJS::Value QCanvasLineImp::endPoint_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasLineImp::endPoint_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQPoint ret;
+ TTQPoint ret;
ret = instance->endPoint( );
return convertToValue( exec, ret );
}
-KJS::Value QCanvasLineImp::rtti_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasLineImp::rtti_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -232,13 +232,13 @@ KJS::Value QCanvasLineImp::rtti_6( KJS::ExecState *exec, KJS::Object &obj, const
}
-KJS::Value QCanvasLineImp::setPen_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasLineImp::setPen_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter QPen
+ // Unsupported parameter TQPen
return KJS::Value();
- TQPen arg0; // Dummy
+ TTQPen arg0; // Dummy
instance->setPen(
arg0 );
@@ -246,7 +246,7 @@ KJS::Value QCanvasLineImp::setPen_7( KJS::ExecState *exec, KJS::Object &obj, con
}
-KJS::Value QCanvasLineImp::moveBy_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasLineImp::moveBy_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
double arg0 = extractDouble(exec, args, 0);
@@ -87,68 +87,68 @@ void QCanvasLineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TQCanvasLine pointer from an Object.
+ * Extract a TTQCanvasLine pointer from an Object.
*/
@@ -87,68 +87,68 @@ void QCanvasLineImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
- // Unsupported parameter TQCanvas *
+ // Unsupported parameter TTQCanvas *
return KJS::Object();